@@ -1,9 +1,11 @@
 from django.http import HttpResponseRedirect
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.views.generic import CreateView
 from django_images.models import Image
 
 from braces.views import JSONResponseMixin, LoginRequiredMixin
+from django_images.models import Thumbnail
 
 from .forms import ImageForm
 
@@ -20,6 +22,8 @@ class CreateImage(JSONResponseMixin, LoginRequiredMixin, CreateView):
 
     def form_valid(self, form):
         image = form.save()
+        for size in settings.IMAGE_SIZES.keys():
+            Thumbnail.objects.get_or_create_at_size(image.pk, size)
         return self.render_json_response({
             'success': {
                 'id': image.id
